@@ -1,6 +1,7 @@
 fboxplot <- function (data, plot.type = c("functional", "bivariate"), type = c("bag", 
     "hdr"), alpha = c(0.01, 0.5), factor = 2.57, na.rm = TRUE,
-    xlab = data$xname, ylab = data$yname, ...) 
+    xlab = data$xname, ylab = data$yname, shadecols = gray((9:1)/10), 
+    pointcol = 1, ...) 
 {
     op <- par(no.readonly = TRUE)
     type <- match.arg(type)
@@ -19,7 +20,7 @@ fboxplot <- function (data, plot.type = c("functional", "bivariate"), type = c("
         sco = PCAproj(t(data$y))$scores 
         if (type == "bag") 
             bbag(data, factor, ...)
-        else bhdr(data, alpha, ...)
+        else bhdr(data, alpha, shadecols = shadecols, pointcol = pointcol, ...)
         exit.restore <- function()
         {
           par(op)
